﻿using System;
using System.Drawing;
using System.Windows.Forms;

using Steema.TeeChart.Drawing;
using Steema.TeeChart.Styles;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            Text = "Bar 클래스 : StackGroup 속성을 사용해 스택 그룹핑하기";

            this.seriesCountComboBox.DropDownStyle = ComboBoxStyle.DropDownList;

            this.seriesCountComboBox.Items.Add(1);
            this.seriesCountComboBox.Items.Add(2);
            this.seriesCountComboBox.Items.Add(3);
            this.seriesCountComboBox.Items.Add(4);
            this.seriesCountComboBox.Items.Add(5);

            this.tChart.Panel.Pen = new ChartPen(Color.Black);

            for(int i = 0; i < 5; i++)
            {
                Bar bar = new Bar();

                bar.Color         = GetBarColor(i);
                bar.MultiBar      = MultiBars.Stacked;
                bar.Marks.Visible = false;

                bar.FillSampleValues(5);

                this.tChart.Series.Add(bar);
            }

            Load                                          += Form_Load;
            this.seriesCountComboBox.SelectedIndexChanged += seriesCountComboBox_SelectedIndexChanged;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region 폼 로드시 처리하기 - Form_Load(sender, e)

        /// <summary>
        /// 폼 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Form_Load(object sender, EventArgs e)
        {
            this.seriesCountComboBox.SelectedIndex = 2;
        }

        #endregion
        #region 시리즈 수 콤보 박스 선택 인덱스 변경시 처리하기 - seriesCountComboBox_SelectedIndexChanged(sender, e)

        /// <summary>
        /// 시리즈 수 콤보 박스 선택 인덱스 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void seriesCountComboBox_SelectedIndexChanged(object sender, EventArgs e)
        {
            int i;

            for(i = 0; i <= this.seriesCountComboBox.SelectedIndex; i++)
            {
                (this.tChart.Series[i] as Bar).StackGroup = 0;
            }

            for(i = this.seriesCountComboBox.SelectedIndex+1; i < this.tChart.Series.Count; i++)
            {
                (this.tChart.Series[i] as Bar).StackGroup = 1;
            }
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////// Function

        #region 바 색상 구하기 - GetBarColor(index)

        /// <summary>
        /// 바 색상 구하기
        /// </summary>
        /// <param name="index">인덱스</param>
        /// <returns>바 색상</returns>
        private Color GetBarColor(int index)
        {
            switch(index)
            {
                case 0 : return Color.FromArgb(178, 255, 0  , 0  );
                case 1 : return Color.FromArgb(178, 0  , 128, 0  );
                case 2 : return Color.FromArgb(178, 255, 255, 0  );
                case 3 : return Color.FromArgb(178, 0  , 0  , 255);
                case 4 : return Color.FromArgb(178, 255, 128, 0  );
            }

            return Color.Transparent;
        }

        #endregion
    }
}